@@ -1,7 +1,8 @@
-from bloxplorer.utils import Request
+from bloxplorer.constants import http
+from bloxplorer.utils import AsyncRequest, SyncRequest
 
 
-class Addresses(Request):
+class SyncAddresses(SyncRequest):
     """
     Wrapper class around the Esplora Addresses endpoint.
 
@@ -9,9 +10,6 @@ class Addresses(Request):
     <https://github.com/Blockstream/esplora/blob/master/API.md#addresses>`_
     """
 
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-
     def get(self, address, **kwargs):
         r"""
         Get information about an address.
@@ -21,7 +19,7 @@ class Addresses(Request):
 
         :return: :class: `Response` object.
         """
-        return self.make_request('GET', f'address/{address}', **kwargs)
+        return self.make_request(http.GET, f'address/{address}', **kwargs)
 
     def get_scripthash(self, hash, **kwargs):
         r"""
@@ -32,7 +30,7 @@ class Addresses(Request):
 
         :return: :class: `Response` object.
         """
-        return self.make_request('GET', f'scripthash/{hash}', **kwargs)
+        return self.make_request(http.GET, f'scripthash/{hash}', **kwargs)
 
     def get_tx_history(self, address, **kwargs):
         r"""
@@ -46,7 +44,7 @@ class Addresses(Request):
 
         :return: :class: `Response` object.
         """
-        return self.make_request('GET', f'address/{address}/txs', **kwargs)
+        return self.make_request(http.GET, f'address/{address}/txs', **kwargs)
 
     def get_scripthash_tx_history(self, hash, **kwargs):
         r"""
@@ -60,7 +58,7 @@ class Addresses(Request):
 
         :return: :class: `Response` object.
         """
-        return self.make_request('GET', f'scripthash/{hash}/txs', **kwargs)
+        return self.make_request(http.GET, f'scripthash/{hash}/txs', **kwargs)
 
     def get_confirmed_tx_history(self, address, last_seen_txid=None, **kwargs):
         r"""
@@ -77,7 +75,7 @@ class Addresses(Request):
         path = f'address/{address}/txs/chain'
         if last_seen_txid is not None:
             path += f'/{last_seen_txid}'
-        return self.make_request('GET', path, **kwargs)
+        return self.make_request(http.GET, path, **kwargs)
 
     def get_confirmed_scripthash_tx_history(self, hash, last_seen_txid=None, **kwargs):
         r"""
@@ -95,7 +93,7 @@ class Addresses(Request):
         path = f'scripthash/{hash}/txs/chain'
         if last_seen_txid is not None:
             path += f'/{last_seen_txid}'
-        return self.make_request('GET', path, **kwargs)
+        return self.make_request(http.GET, path, **kwargs)
 
     def get_unconfirmed_tx_history(self, address, **kwargs):
         r"""
@@ -107,7 +105,7 @@ class Addresses(Request):
 
         :return: :class: `Response` object.
         """
-        return self.make_request('GET', f'address/{address}/txs/mempool', **kwargs)
+        return self.make_request(http.GET, f'address/{address}/txs/mempool', **kwargs)
 
     def get_unconfirmed_scripthash_tx_history(self, hash, **kwargs):
         r"""
@@ -119,7 +117,7 @@ class Addresses(Request):
 
         :return: :class: `Response` object.
         """
-        return self.make_request('GET', f'scripthash/{hash}/txs/mempool', **kwargs)
+        return self.make_request(http.GET, f'scripthash/{hash}/txs/mempool', **kwargs)
 
     def get_utxo(self, address, **kwargs):
         r"""
@@ -130,7 +128,7 @@ class Addresses(Request):
 
         :return: :class: `Response` object.
         """
-        return self.make_request('GET', f'address/{address}/utxo', **kwargs)
+        return self.make_request(http.GET, f'address/{address}/utxo', **kwargs)
 
     def get_scripthash_utxo(self, hash, **kwargs):
         r"""
@@ -141,7 +139,7 @@ class Addresses(Request):
 
         :return: :class: `Response` object.
         """
-        return self.make_request('GET', f'scripthash/{hash}/utxo', **kwargs)
+        return self.make_request(http.GET, f'scripthash/{hash}/utxo', **kwargs)
 
     def get_address_prefix(self, prefix, **kwargs):
         r"""
@@ -153,16 +151,45 @@ class Addresses(Request):
 
         :return: :class: `Response` object.
         """
-        return self.make_request('GET', f'address-prefix/{prefix}', **kwargs)
+        return self.make_request(http.GET, f'address-prefix/{prefix}', **kwargs)
 
-    @staticmethod
-    def get_address_type(address):
-        """
-        Get the Bitcoin address type.
-        Not available for Liquid.
 
-        :param address: The alphanumeric Bitcoin address
+class AsyncAddresses(AsyncRequest):
+    async def get(self, address, **kwargs):
+        return await self.make_request(http.GET, f'address/{address}', **kwargs)
 
-        :return: String representing the address type (P2PKH, P2SH, etc.)
-        """
-        pass
+    async def get_scripthash(self, hash, **kwargs):
+        return await self.make_request(http.GET, f'scripthash/{hash}', **kwargs)
+
+    async def get_tx_history(self, address, **kwargs):
+        return await self.make_request(http.GET, f'address/{address}/txs', **kwargs)
+
+    async def get_scripthash_tx_history(self, hash, **kwargs):
+        return await self.make_request(http.GET, f'scripthash/{hash}/txs', **kwargs)
+
+    async def get_confirmed_tx_history(self, address, last_seen_txid=None, **kwargs):
+        path = f'address/{address}/txs/chain'
+        if last_seen_txid is not None:
+            path += f'/{last_seen_txid}'
+        return await self.make_request(http.GET, path, **kwargs)
+
+    async def get_confirmed_scripthash_tx_history(self, hash, last_seen_txid=None, **kwargs):
+        path = f'scripthash/{hash}/txs/chain'
+        if last_seen_txid is not None:
+            path += f'/{last_seen_txid}'
+        return await self.make_request(http.GET, path, **kwargs)
+
+    async def get_unconfirmed_tx_history(self, address, **kwargs):
+        return await self.make_request(http.GET, f'address/{address}/txs/mempool', **kwargs)
+
+    async def get_unconfirmed_scripthash_tx_history(self, hash, **kwargs):
+        return await self.make_request(http.GET, f'scripthash/{hash}/txs/mempool', **kwargs)
+
+    async def get_utxo(self, address, **kwargs):
+        return await self.make_request(http.GET, f'address/{address}/utxo', **kwargs)
+
+    async def get_scripthash_utxo(self, hash, **kwargs):
+        return await self.make_request(http.GET, f'scripthash/{hash}/utxo', **kwargs)
+
+    async def get_address_prefix(self, prefix, **kwargs):
+        return await self.make_request(http.GET, f'address-prefix/{prefix}', **kwargs)
