@@ -1,7 +1,8 @@
-from bloxplorer.utils import Request
+from bloxplorer.constants import http
+from bloxplorer.utils import AsyncRequest, SyncRequest
 
 
-class Blocks(Request):
+class SyncBlocks(SyncRequest):
     """
     Wrapper class around the Esplora Blocks endpoint.
 
@@ -9,10 +10,6 @@ class Blocks(Request):
     <https://github.com/Blockstream/esplora/blob/master/API.md#blocks>`_
     """
 
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        # self.cache = {}
-
     def get(self, hash, **kwargs):
         r"""
         Returns information about a block.
@@ -23,7 +20,7 @@ class Blocks(Request):
 
         :return: :class: `Response` object.
         """
-        return self.make_request('GET', f'block/{hash}', **kwargs)
+        return self.make_request(http.GET, f'block/{hash}', **kwargs)
 
     def get_status(self, hash, **kwargs):
         r"""
@@ -35,7 +32,7 @@ class Blocks(Request):
 
         :return: :class: `Response` object.
         """
-        return self.make_request('GET', f'block/{hash}/status', **kwargs)
+        return self.make_request(http.GET, f'block/{hash}/status', **kwargs)
 
     def get_txs(self, hash, start_index=None, **kwargs):
         r"""
@@ -53,7 +50,7 @@ class Blocks(Request):
         path = f'block/{hash}/txs'
         if start_index is not None:
             path = f'{path}/{start_index}'
-        return self.make_request('GET', path, **kwargs)
+        return self.make_request(http.GET, path, **kwargs)
 
     def get_txids(self, hash, index=None, **kwargs):
         r"""
@@ -68,7 +65,7 @@ class Blocks(Request):
         :return: :class: `Response` object.
         """
         path = f'block/{hash}/txid/{index}' if index is not None else f'block/{hash}/txids'
-        return self.make_request('GET', path, **kwargs)
+        return self.make_request(http.GET, path, **kwargs)
 
     def get_height(self, height, **kwargs):
         r"""
@@ -79,7 +76,7 @@ class Blocks(Request):
 
         :return: :class: `Response` object.
         """
-        return self.make_request('GET', f'block-height/{height}', **kwargs)
+        return self.make_request(http.GET, f'block-height/{height}', **kwargs)
 
     def get_blocks(self, start_height=None, **kwargs):
         r"""
@@ -90,10 +87,10 @@ class Blocks(Request):
 
         :return: :class: `Response` object.
         """
-        path = f'blocks'
+        path = 'blocks'
         if start_height is not None:
             path = f'{path}/{start_height}'
-        return self.make_request('GET', path, **kwargs)
+        return self.make_request(http.GET, path, **kwargs)
 
     def get_last_height(self, **kwargs):
         r"""
@@ -103,7 +100,7 @@ class Blocks(Request):
 
         :return: :class: `Response` object.
         """
-        return self.make_request('GET', 'blocks/tip/height', **kwargs)
+        return self.make_request(http.GET, 'blocks/tip/height', **kwargs)
 
     def get_last_hash(self, **kwargs):
         r"""
@@ -113,4 +110,37 @@ class Blocks(Request):
 
         :return: :class: `Response` object.
         """
-        return self.make_request('GET', 'blocks/tip/hash', **kwargs)
+        return self.make_request(http.GET, 'blocks/tip/hash', **kwargs)
+
+
+class AsyncBlocks(AsyncRequest):
+    async def get(self, hash, **kwargs):
+        return await self.make_request(http.GET, f'block/{hash}', **kwargs)
+
+    async def get_status(self, hash, **kwargs):
+        return await self.make_request(http.GET, f'block/{hash}/status', **kwargs)
+
+    async def get_txs(self, hash, start_index=None, **kwargs):
+        path = f'block/{hash}/txs'
+        if start_index is not None:
+            path = f'{path}/{start_index}'
+        return await self.make_request(http.GET, path, **kwargs)
+
+    async def get_txids(self, hash, index=None, **kwargs):
+        path = f'block/{hash}/txid/{index}' if index is not None else f'block/{hash}/txids'
+        return await self.make_request(http.GET, path, **kwargs)
+
+    async def get_height(self, height, **kwargs):
+        return await self.make_request(http.GET, f'block-height/{height}', **kwargs)
+
+    async def get_blocks(self, start_height=None, **kwargs):
+        path = 'blocks'
+        if start_height is not None:
+            path = f'{path}/{start_height}'
+        return await self.make_request(http.GET, path, **kwargs)
+
+    async def get_last_height(self, **kwargs):
+        return await self.make_request(http.GET, 'blocks/tip/height', **kwargs)
+
+    async def get_last_hash(self, **kwargs):
+        return await self.make_request(http.GET, 'blocks/tip/hash', **kwargs)
