@@ -1,7 +1,8 @@
-from bloxplorer.utils import Request
+from bloxplorer.constants import http
+from bloxplorer.utils import AsyncRequest, SyncRequest
 
 
-class Fees(Request):
+class SyncFees(SyncRequest):
     """
     Wrapper class around the Esplora Fee Estimates endpoint.
 
@@ -22,4 +23,9 @@ class Fees(Request):
 
         :return: :class: `Response` object.
         """
-        return self.make_request('GET', 'fee-estimates', **kwargs)
+        return self.make_request(http.GET, 'fee-estimates', **kwargs)
+
+
+class AsyncFees(AsyncRequest):
+    async def get_estimates(self, **kwargs):
+        return await self.make_request(http.GET, 'fee-estimates', **kwargs)
