@@ -1,7 +1,8 @@
-from bloxplorer.utils import Request
+from bloxplorer.constants import http
+from bloxplorer.utils import AsyncRequest, SyncRequest
 
 
-class Mempool(Request):
+class SyncMempool(SyncRequest):
     """
     Wrapper class around the Esplora Mempool endpoint.
 
@@ -20,7 +21,7 @@ class Mempool(Request):
 
         :return: :class: `Response` object.
         """
-        return self.make_request('GET', 'mempool', **kwargs)
+        return self.make_request(http.GET, 'mempool', **kwargs)
 
     def get_txids(self, **kwargs):
         r"""
@@ -31,7 +32,7 @@ class Mempool(Request):
 
         :return: :class: `Response` object.
         """
-        return self.make_request('GET', 'mempool/txids', **kwargs)
+        return self.make_request(http.GET, 'mempool/txids', **kwargs)
 
     def get_latest_txs(self, **kwargs):
         r"""
@@ -41,4 +42,16 @@ class Mempool(Request):
 
         :return: :class: `Response` object.
         """
-        return self.make_request('GET', 'mempool/recent', **kwargs)
+        return self.make_request(http.GET, 'mempool/recent', **kwargs)
+
+
+class AsyncMempool(AsyncRequest):
+
+    async def get(self, **kwargs):
+        return await self.make_request(http.GET, 'mempool', **kwargs)
+
+    async def get_txids(self, **kwargs):
+        return await self.make_request(http.GET, 'mempool/txids', **kwargs)
+
+    async def get_latest_txs(self, **kwargs):
+        return await self.make_request(http.GET, 'mempool/recent', **kwargs)
